bayespy.inference.vmp.nodes.expfamily.ExponentialFamily.unobserve
=================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.expfamily

.. automethod:: ExponentialFamily.unobserve